- word
A word which should be returned as plural if count is not equal to 1.
- count
A number to apply to word
- plural
How to make the plural; defaults to an "s" which is added at the end of the word.
Can be anything. See add_or_swap.
- add_or_swap
Choose between add (add the plural form (e.g. "s") onto the end; e.g. house
becomes houses) and swap (swap for the plural form; e.g. mouse becomes mice)
- include_number
Logical. If TRUE, the number will be turned into text, as per num_to_text() (if it is a whole number, )
- sentence_start
Logical. Defaults to FALSE, which results in only numbers 1-10 being written out in full.
If TRUE, numbers 11-999 are written out in full if included. (If include_number is FALSE, the first letter of word is capitalised.)
- zero_or_no
Prefered string to use where count == 0. Defaults to "no". Can be anything.
- uk_or_us
Only used if include_number == TRUE. Defaults to UK which adds an "and" between "hundred" and other numbers
(e.g. "One hundred and five"). If "US" is chosen, the "and" is removed (e.g. "One hundred five").
- big_mark
Passed to num_to_text. Defaults to "," (e.g. "1,999")