Learn R Programming

verbaliseR (version 0.1)

restore_capitals: Restore sustom capitalisation in a string

Description

Restore sustom capitalisation in a string

Usage

restore_capitals(x, items_to_capitalise)

Value

A string with restored capitals

Arguments

x

A string in which capitalisation needs to be restored

items_to_capitalise

Whole words or acronyms in which capitalisation must be retained; special characters can be included (e.g. "R2-D2")

Examples

Run this code
x <- "Should i tell c-3po the french call him z-6po?"
restore_capitals(x, c("I", "C-3PO", "French", "Z-6PO"))

Run the code above in your browser using DataLab